==> commands-1.3.1-sources.jar: org/jclouds/karaf/commands/compute/completer/ImageCompleter.java <==
/*
 * Copyright (C) 2011, the original authors
 *
 * ====================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ====================================================================
 */

package org.jclouds.karaf.commands.compute.completer;

import java.util.Set;
import org.apache.karaf.shell.console.Completer;
import org.jclouds.compute.ComputeService;
import org.jclouds.compute.domain.Image;
import org.jclouds.karaf.commands.cache.CacheProvider;

public class ImageCompleter extends ComputeCompleterSupport implements Completer {

    public ImageCompleter() {
        cache = CacheProvider.getCache("image");
    }

    @Override
    public void updateCache(ComputeService computeService) {
        if (computeService != null) {
            Set<? extends Image> images = computeService.listImages();
            if (images != null) {
                for (Image image : images) {
                    cache.add(image.getId());
                }
            }
        }
    }
}

==> commands-1.4.0-rc.3_1-sources.jar: org/jclouds/karaf/commands/compute/completer/ImageCompleter.java <==
/*
 * Copyright (C) 2011, the original authors
 *
 * ====================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ====================================================================
 */

package org.jclouds.karaf.commands.compute.completer;

import org.apache.karaf.shell.console.Completer;
import org.jclouds.compute.ComputeService;
import org.jclouds.compute.domain.Image;

import java.util.Set;

public class ImageCompleter extends ComputeCompleterSupport implements Completer {

    public void init() {
        cache = cacheProvider.getProviderCacheForType("image");
    }

    @Override
    public void updateOnAdded(ComputeService computeService) {
        if (computeService != null) {
            Set<? extends Image> images = computeService.listImages();
            if (images != null) {
                for (Image image : images) {
                    cache.put(computeService.getContext().getProviderSpecificContext().getId(),image.getId());
                }
            }
        }
    }
}
